@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "chunkdownload.h"
 
@@ -136,7 +122,7 @@ bool ChunkDownload::piece(const Piece &p, bool &ok)
 
 void ChunkDownload::releaseAllPDs()
 {
-    for (PieceDownloader *pd : qAsConst(pdown)) {
+    for (PieceDownloader *pd : std::as_const(pdown)) {
         pd->release();
         sendCancels(pd);
         disconnect(pd, &PieceDownloader::timedout, this, &ChunkDownload::onTimeout);
@@ -360,7 +346,7 @@ QString ChunkDownload::getPieceDownloaderName() const
 Uint32 ChunkDownload::getDownloadSpeed() const
 {
     Uint32 r = 0;
-    for (PieceDownloader *pd : qAsConst(pdown))
+    for (PieceDownloader *pd : std::as_const(pdown))
         r += pd->getDownloadRate();
 
     return r;
