@@ -7,11 +7,10 @@
 #include <QtGlobal>
 #include <errno.h>
 #include <stdlib.h>
-#include <sys/socket.h>
 #include <sys/types.h>
 #include <util/log.h>
 #include <util/sha1hash.h>
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
@@ -20,7 +19,6 @@
 #endif
 #include "rc4encryptor.h"
 #include <net/socketmonitor.h>
-#include <netinet/tcp.h>
 #include <util/functions.h>
 
 using namespace bt;
