@@ -8,6 +8,7 @@
 #include <QTest>
 
 #include <net/wakeuppipe.h>
+#include <util/functions.h>
 #include <util/log.h>
 #include <util/pipe.h>
 
@@ -23,6 +24,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void initTestCase()
     {
+        bt::InitLibKTorrent();
         bt::InitLog("wakeuppipetest.log");
     }
 
