@@ -26,7 +26,7 @@ namespace bt
 static QString SanityzeName(const QString &name)
 {
     QString ret = name;
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     char invalid[] = {'<', '>', ':', '"', '/', '\\', '|', '?', '*'};
     for (int i = 0; i < 9; i++) {
         if (ret.contains(invalid[i]))
@@ -109,7 +109,7 @@ void Torrent::load(const QByteArray &data, bool verbose)
         if (c)
             comments = c->data().toString(text_codec);
 
-        BValueNode *announce = dict->getValue(QByteArrayLiteral("announce"));
+        const BValueNode *announce = dict->getValue(QByteArrayLiteral("announce"));
         BListNode *nodes = dict->getList(QByteArrayLiteral("nodes"));
         // if (!announce && !nodes)
         //  throw Error(i18n("Torrent has no announce or nodes field."));
