@@ -13,7 +13,12 @@
 #include <string>
 #include <sys/stat.h>
 #include <sys/types.h>
+
+#ifndef Q_OS_WIN
 #include <unistd.h>
+#else
+#include <windows.h>
+#endif
 
 #include <QDir>
 #include <QFile>
@@ -34,7 +39,7 @@
 #include "file.h"
 #include "functions.h"
 #include "log.h"
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 #include "win32.h"
 #endif
 
@@ -69,7 +74,7 @@ typedef int64_t __s64;
 #define O_LARGEFILE 0
 #endif
 
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
 #ifdef Q_OS_LINUX
 #include <mntent.h>
 #endif
@@ -100,7 +105,7 @@ void MakePath(const QString &dir, bool nothrow)
 {
     QStringList sl = dir.split(bt::DirSeparator(), Qt::SkipEmptyParts);
     QString ctmp;
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
     ctmp += bt::DirSeparator();
 #endif
 
@@ -124,7 +129,7 @@ void MakeFilePath(const QString &file, bool nothrow)
 {
     QStringList sl = file.split(bt::DirSeparator());
     QString ctmp;
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
     ctmp += bt::DirSeparator();
 #endif
 
@@ -145,12 +150,16 @@ void MakeFilePath(const QString &file, bool nothrow)
 
 void SymLink(const QString &link_to, const QString &link_url, bool nothrow)
 {
-    if (symlink(QFile::encodeName(link_to).constData(), QFile::encodeName(link_url).constData()) != 0) {
+    const QFile symlink_file{link_to};
+    const QFile target_file{link_url};
+    std::error_code error;
+    std::filesystem::create_directory_symlink(target_file.filesystemFileName(), symlink_file.filesystemFileName(), error);
+    if (error) {
+        const auto error_msg = QString::fromStdString(error.message());
         if (!nothrow)
-            throw Error(i18n("Cannot symlink %1 to %2: %3", link_url, link_to, QString::fromUtf8(strerror(errno))));
+            throw Error(i18n("Cannot symlink %1 to %2: %3", link_url, link_to, error_msg));
         else
-            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot symlink %1 to %2: %3").arg(link_url, link_to, QString::fromUtf8(strerror(errno)))
-                                      << endl;
+            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot symlink %1 to %2: %3").arg(link_url, link_to, error_msg) << endl;
     }
 }
 
@@ -327,6 +336,8 @@ void TruncateFile(int fd, Uint64 size, bool quick)
     if (quick) {
 #ifdef HAVE_FTRUNCATE64
         if (ftruncate64(fd, size) == -1)
+#elif defined Q_OS_WIN
+        if (_chsize_s(fd, size) != 0)
 #else
         if (ftruncate(fd, size) == -1)
 #endif
@@ -334,17 +345,16 @@ void TruncateFile(int fd, Uint64 size, bool quick)
     } else {
 #ifdef HAVE_POSIX_FALLOCATE64
         if (posix_fallocate64(fd, 0, size) != 0)
-            throw Error(i18n("Cannot expand file: %1", QString::fromUtf8(strerror(errno))));
 #elif HAVE_POSIX_FALLOCATE
         if (posix_fallocate(fd, 0, size) != 0)
-            throw Error(i18n("Cannot expand file: %1", QString::fromUtf8(strerror(errno))));
 #elif HAVE_FTRUNCATE64
         if (ftruncate64(fd, size) == -1)
-            throw Error(i18n("Cannot expand file: %1", QString::fromUtf8(strerror(errno))));
+#elif defined Q_OS_WIN
+        if (_chsize_s(fd, size) != 0)
 #else
         if (ftruncate(fd, size) == -1)
-            throw Error(i18n("Cannot expand file: %1", QString::fromUtf8(strerror(errno))));
 #endif
+            throw Error(i18n("Cannot expand file: %1", QString::fromUtf8(strerror(errno))));
     }
 }
 
@@ -394,7 +404,7 @@ bool FreeDiskSpace(const QString &path, Uint64 &bytes_free)
 
         return false;
     }
-#elif defined(Q_WS_WIN)
+#elif defined(Q_OS_WIN)
 #ifdef UNICODE
     LPCWSTR tpath = (LPCWSTR)path.utf16();
 #else
@@ -518,7 +528,7 @@ QString ShortenFileName(const QString &path, int extra_number)
 Uint64 DiskUsage(const QString &filename)
 {
     Uint64 ret = 0;
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
 #ifdef HAVE_STAT64
     struct stat64 sb;
     if (stat64(QFile::encodeName(filename).constData(), &sb) == 0)
@@ -541,7 +551,7 @@ Uint64 DiskUsage(const QString &filename)
 Uint64 DiskUsage(int fd)
 {
     Uint64 ret = 0;
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
 #ifdef HAVE_FSTAT64
     struct stat64 sb;
     if (fstat64(fd, &sb) == 0)
