@@ -5,16 +5,24 @@
 */
 
 #include "functions.h"
-#include <arpa/inet.h>
+
 #include <errno.h>
 #include <gcrypt.h>
+#include <sys/types.h>
+
+#ifndef Q_OS_WIN
+#include <arpa/inet.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #include <sys/resource.h>
 #include <sys/socket.h>
-#include <sys/time.h>
-#include <sys/types.h>
 #include <unistd.h>
+#else
+#include <Winsock2.h>
+#include <stdio.h>
+#endif
+
+#include <chrono>
 
 #include <QDir>
 #include <QMimeDatabase>
@@ -56,19 +64,21 @@ TimeStamp global_time_stamp = 0;
 
 Uint64 Now()
 {
-    struct timeval tv;
-    gettimeofday(&tv, nullptr);
-    global_time_stamp = (Uint64)tv.tv_sec * 1000 + (Uint64)tv.tv_usec * 0.001;
-    return global_time_stamp;
+    using namespace std::chrono;
+    return duration_cast<milliseconds>(system_clock::now().time_since_epoch()).count();
 }
 
 Uint32 MaxOpenFiles()
 {
     static Uint32 max_open = 0;
     if (max_open == 0) {
+#ifndef Q_OS_WIN
         struct rlimit lim;
         getrlimit(RLIMIT_NOFILE, &lim);
         max_open = lim.rlim_cur;
+#else
+        max_open = static_cast<Uint32>(_getmaxstdio());
+#endif
     }
 
     return max_open;
@@ -101,13 +111,24 @@ bool OpenFileAllowed()
 bool MaximizeLimits()
 {
     // first get the current limits
+#ifndef Q_OS_WIN
     struct rlimit lim;
     getrlimit(RLIMIT_NOFILE, &lim);
+    const auto current_limit = lim.rlim_cur;
+    const auto max_limit = lim.rlim_max;
+#else
+    const auto current_limit = _getmaxstdio();
+    constexpr auto max_limit = 8192;
+#endif
 
-    if (lim.rlim_cur != lim.rlim_max) {
-        Out(SYS_GEN | LOG_DEBUG) << "Current limit for number of files : " << lim.rlim_cur << " (" << lim.rlim_max << " max)" << endl;
+    if (current_limit != max_limit) {
+        Out(SYS_GEN | LOG_DEBUG) << "Current limit for number of files : " << current_limit << " (" << max_limit << " max)" << endl;
+#ifndef Q_OS_WIN
         lim.rlim_cur = lim.rlim_max;
         if (setrlimit(RLIMIT_NOFILE, &lim) < 0) {
+#else
+        if (_setmaxstdio(max_limit) == -1) {
+#endif
             Out(SYS_GEN | LOG_DEBUG) << "Failed to maximize file limit : " << QString::fromUtf8(strerror(errno)) << endl;
             return false;
         }
@@ -115,6 +136,10 @@ bool MaximizeLimits()
         Out(SYS_GEN | LOG_DEBUG) << "File limit already at maximum " << endl;
     }
 
+#ifdef Q_OS_WIN
+    // It is not possible to increase stack/heap size on Windows
+    return false;
+#else
     getrlimit(RLIMIT_DATA, &lim);
     if (lim.rlim_cur != lim.rlim_max) {
         Out(SYS_GEN | LOG_DEBUG) << "Current limit for data size : " << lim.rlim_cur << " (" << lim.rlim_max << " max)" << endl;
@@ -128,6 +153,7 @@ bool MaximizeLimits()
     }
 
     return true;
+#endif
 }
 
 static QString net_iface = QString();
@@ -240,7 +266,7 @@ double Percentage(const TorrentStats &s)
     }
 }
 
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 static bool InitWindowsSocketsAPI()
 {
     static bool initialized = false;
@@ -285,7 +311,7 @@ bool InitLibKTorrent()
 {
     MaximizeLimits();
     bool ret = InitGCrypt();
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
     ret = InitWindowsSocketsAPI() && ret;
 #endif
     return ret;
