@@ -3,14 +3,14 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
+
+#ifndef Q_OS_WIN
 #include "signalcatcher.h"
 #include "log.h"
 #include <klocalizedstring.h>
 #include <sys/socket.h>
 #include <unistd.h>
 
-#ifndef Q_WS_WIN
-
 namespace bt
 {
 sigjmp_buf sigbus_env;
