@@ -10,7 +10,6 @@
 #include <QTextStream>
 #include <QTimer>
 
-#include <unistd.h>
 #include <util/functions.h>
 #include <util/log.h>
 #include <util/sha1hash.h>
@@ -147,6 +146,7 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
+        bt::InitLibKTorrent();
         bt::InitLog("transmittest.log", false, true, false);
 
         port = 50000;
